Learn R Programming

BTLLasso (version 0.1-5)

Buli1516: Bundesliga Data 2015/16 (Buli1516)

Description

Data from the German Bundesliga from the season 2015/16. The data contain all 306 matches of the season treated as paired comparisons with 5 different response categories. Additionally, different match-specific covariates are given as, for example, the percentage of ball possession or the total distance ran per team and per match.

Arguments

Format

A list containing data from the German Bundesliga with 306 observations. The list contains both information on the response (paired comparisons) and different covariates.
Y5
A response.BTLLasso object with 5 response categories for the Buli1516 data including
  • response: Ordinal paired comparison response vector
  • first.object: Vector containing the first-named team per paired comparison (home team)
  • second.object: Vector containing the second-named team per paired comparison (away team)
  • subject: Vector containing a match-day identifier per paired comparison
Y3
A response.BTLLasso object with 3 response categories for the Buli1516 data including
  • response: Ordinal paired comparison response vector
  • first.object: Vector containing the first-named team per paired comparison (home team)
  • second.object: Vector containing the second-named team per paired comparison (away team)
  • subject: Vector containing a match-day identifier per paired comparison
Z1
Matrix containing all team-match-specific covariates
  • Distance: Total amount of km run
  • BallPossession: Percentage of ball possession
  • TacklingRate: Rate of won tacklings
  • ShotsonGoal: Total number of shots on goal
  • CompletionRate: Percentage of passes reaching teammates
  • FoulsSuffered: Number of fouls suffered
  • Offside: Number of offsides (in attack)

Z2
Matrix containing all the average market values of the teams as a team-specific covariate

References

Schauberger, Gunther and Tutz, Gerhard (2015): Modelling Heterogeneity in Paired Comparison Data - an L1 Penalty Approach with an Application to Party Preference Data, Department of Statistics, LMU Munich, Technical Report 183

Schauberger, Gunther, Groll Andreas and Tutz, Gerhard (2016): Modelling Football Results in the German Bundesliga Using Match-specific Covariates, Department of Statistics, LMU Munich, Technical Report 197

Examples

Run this code

data(Buli1516)

Run the code above in your browser using DataLab