Learn R Programming

BTLLasso (version 0.1-2)

GLES: German Longitudinal Election Study (GLES)

Description

Data from the German Longitudinal Election Study (GLES), see Rattinger et al. (2014). The GLES is a long-term study of the German electoral process. It collects pre- and post-election data for several federal elections, the data used here originate from the pre-election study for 2013.

Usage

data("GLES")

Arguments

Format

A data frame with 1155 observations on the following 18 variables.
SPD vs FDP
Ordinal paired comparison between SPD and FDP
SPD vs Left Party
Ordinal paired comparison between SPD and Left Party
SPD vs Greens
Ordinal paired comparison between SPD and Greens
SPD vs CDU_CSU
Ordinal paired comparison between SPD and CDU/CSU
FDP vs Left Party
Ordinal paired comparison between FDP and Left Party
FDP vs Greens
Ordinal paired comparison between FDP and Greens
FDP vs CDU_CSU
Ordinal paired comparison between FDP and CDU/CSU
Left Party vs Greens
Ordinal paired comparison between Left Party and Greens
Left Party vs CDU_CSU
Ordinal paired comparison between Left Party and CDU/CSU
Greens vs CDU_CSU
Ordinal paired comparison between Greens and CDU/CSU
Age
Age in years
Gender
0: male, 1: female
EastWest
0: West Germany, 1:East Germany
PersEcon
Personal economic situation, 1: good or very good, 0: else
Abitur
School leaving certificate, 1: Abitur/A levels, 0: else
Unemployment
1: currently unemployed, 0: else
Church
Frequency of attendence in a church/synagogue/mosque/..., 1: at least once a month, 0: else
Migration
Have you been a German citizen since birth? 1: yes, 0: no

Details

Variables 1 to 10 represent the response, variables 11 to 18 represent the subject-specific covariates. The response variables are ordinal, with values from 1 to 5. Low values represent string preference of the first-names party, high values represent strong preference of the last-named party.

References

Rattinger, H., S. Rossteutscher, R. Schmitt-Beck, B. Wessels, and C. Wolf (2014): Pre-election cross section (GLES 2013). GESIS Data Archive, Cologne ZA5700 Data file Version 2.0.0.

Schauberger, Gunther and Tutz, Gerhard (2015): Modelling Heterogeneity in Paired Comparison Data - an L1 Penalty Approach with an Application to Party Preference Data, Department of Statistics, LMU Munich, Technical Report 183

Examples

Run this code
data(GLES)

Run the code above in your browser using DataLab