Learn R Programming

BTLLasso (version 0.1-1)

print.cv.BTLLasso: Print function for cv.BTLLasso objects

Description

Prints the most important output of cv.BTLLasso objects.

Usage

## S3 method for class 'cv.BTLLasso':
print(x, ...)

Arguments

x
cv.BTLLasso object
...
possible further arguments for print command

Value

  • xcv.BTLLasso object

References

Schauberger, Gunther and Tutz, Gerhard (2015): Modelling Heterogeneity in Paired Comparison Data - an L1 Penalty Approach with an Application to Party Preference Data, Department of Statistics, LMU Munich, Technical Report 183

See Also

cv.BTLLasso

Examples

Run this code
## load data set
data(GLESsmall)

# define response and covariate matrix
X <- scale(GLESsmall[, 11:14])
Y <- as.matrix(GLESsmall[, 1:10])

# vector of subtitles, containing the coding of the single covariates
subs <- c("(in years)","female (1); male (0)",
"East Germany (1); West Germany (0)","(very) good (1); else (0)")

# vector of tuning parameters
lambda <- exp(seq(log(31),log(1),length=50))-1


# compute 10-fold cross-validation
set.seed(5)
m.cv <- cv.BTLLasso(Y = Y, X = X, folds = 10, lambda = lambda, cores = 10)

print(m.cv)

Run the code above in your browser using DataLab