Learn R Programming

BTLLasso (version 0.1-5)

GLES: German Longitudinal Election Study (GLES)

Description

Data from the German Longitudinal Election Study (GLES), see Rattinger et al. (2014). The GLES is a long-term study of the German electoral process. It collects pre- and post-election data for several federal elections, the data used here originate from the pre-election study for 2013.

Arguments

Format

A list containing data from the German Longitudinal Election Study with 2003 (partly incomplete) observations. The list contains both information on the response (paired comparisons) and different covariates.
Y
A response.BTLLasso object for the GLES data including
  • response: Ordinal paired comparison response vector
  • first.object: Vector containing the first-named party per paired comparison
  • second.object: Vector containing the second-named party per paired comparison
  • subject: Vector containing a person identifier per paired comparison
X
Matrix containing all eight person-specific covariates
  • Age: Age in years
  • Gender (0: male, 1: female)
  • EastWest (0: West Germany, 1: East Germany)
  • PersEcon: Personal economic situation, 1: good or very good, 0: else
  • Abitur: School leaving certificate, 1: Abitur/A levels, 0: else
  • Unemployment: 1: currently unemployed, 0: else
  • Church: Frequency of attendence in a church/synagogue/mosque/..., 1: at least once a month, 0: else
  • Migration: Are you a migrant / not German since birth? 1: yes, 0: no

Z1
Matrix containing all four person-party-specific covariates
  • Climate: Self-perceived distance of each person to all five parties with respect to ones attitude towards climate change.
  • SocioEcon: Self-perceived distance of each person to all five parties with respect to ones attitude towards socio-economic issues.
  • Immigration: Self-perceived distance of each person to all five parties with respect to ones attitude towards immigration.

References

Rattinger, H., S. Rossteutscher, R. Schmitt-Beck, B. Wessels, and C. Wolf (2014): Pre-election cross section (GLES 2013). GESIS Data Archive, Cologne ZA5700 Data file Version 2.0.0.

Schauberger, Gunther and Tutz, Gerhard (2015): Modelling Heterogeneity in Paired Comparison Data - an L1 Penalty Approach with an Application to Party Preference Data, Department of Statistics, LMU Munich, Technical Report 183

Schauberger, Gunther, Groll Andreas and Tutz, Gerhard (2016): Modelling Football Results in the German Bundesliga Using Match-specific Covariates, Department of Statistics, LMU Munich, Technical Report 197

Examples

Run this code

data(GLES)

Run the code above in your browser using DataLab